from setuptools import find_packages, setup


setup(
    name="revolt",
    version="0.0.1",
    description="",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Nikita Tsvetkov",
    author_email="nikitanovosibirsk@yandex.com",
    url="https://github.com/nikitanovosibirsk/revolt",
    license="Apache-2.0",
    packages=find_packages(),
    install_requires=[],
    tests_require=[],
)
